@@ -4,7 +4,8 @@ summary.HLSM = function(object,...){
 	call = object$call
 
 	Betas = getBeta(object, ...)
-	if(length(dim(Betas)) == 3){
+	if(!is.null(Betas)){
+	    if(length(dim(Betas)) == 3){
 		est.slopes = lapply(1:dim(Betas)[[3]],
 			function(x){ t(sapply(1:ncol(Betas[,,x]),
 			function(y) data.frame(min = round(min(Betas[,y,x]),3),
@@ -17,6 +18,7 @@ summary.HLSM = function(object,...){
 		Betas = as.matrix(Betas)
 		est.slopes = t(sapply(1:ncol(Betas),function(y) data.frame(min = round(min(Betas[,y]),3), max = round(max(Betas[,y]),3),est.mean = round(mean(Betas[,y]),3), sd = round(sd(Betas[,y]),3), q.25 = round(quantile(Betas[,y],0.025),3), q.975 = round(quantile(Betas[,y],0.975),3)) ) )
 	}
+	}else(est.slopes = NA)
 
 	Intercept = getIntercept(object,...)
 	if(class(Intercept) == 'matrix'){
@@ -26,13 +28,11 @@ summary.HLSM = function(object,...){
       }
 	
 	Alphas = getAlpha(object,...)
-	if(any(Alphas != 0)){
-			est.alpha = data.frame(min = round(min(Alphas),3), max = round(max(Alphas),3), est.mean = round(mean(Alphas),3), sd = round(sd(Alphas),3), q.025 = round(quantile(Alphas,0.025),3), q.975 = round(quantile(Alphas, 0.975),3) )
-		res =  list(call = object$call,
-         est.intercept = est.intercept, est.alpha = est.alpha, est.slopes = est.slopes)
-	}else{
-		res = list(call = object$call,
-         est.intercept = est.intercept, est.slopes = est.slopes)}
+	if(!is.null(Alphas)){
+			est.alpha = data.frame(min = round(min(Alphas),3), max = round(max(Alphas),3), est.mean = round(mean(Alphas),3), sd = round(sd(Alphas),3), q.025 = round(quantile(Alphas,0.025),3), q.975 = round(quantile(Alphas, 0.975),3) ) 
+	}else(est.alpha = NA)
+
+	res =  list(call = object$call,est.intercept = est.intercept, est.slopes = est.slopes, est.alpha = est.alpha)
 
     class(res) = 'summary.HLSM'
     res
